@@ -3,12 +3,10 @@ package NewRelic::Agent::FFI;
 use strict;
 use warnings;
 use 5.010;
-use FFI::Platypus 0.56;
-use FFI::CheckLib ();
 use NewRelic::Agent::FFI::Procedural ();
 
 # ABSTRACT: Perl Agent for NewRelic APM
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 sub new
@@ -191,7 +189,7 @@ NewRelic::Agent::FFI - Perl Agent for NewRelic APM
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
